@@ -214,7 +214,13 @@ impl DTLSConn {
             insecure_skip_verify: config.insecure_skip_verify,
             verify_peer_certificate: config.verify_peer_certificate.take(),
             roots_cas: config.roots_cas,
-            client_cert_verifier: config.client_cert_verifier,
+            client_cert_verifier: if config.client_auth as u8
+                >= ClientAuthType::VerifyClientCertIfGiven as u8
+            {
+                Some(rustls::AllowAnyAuthenticatedClient::new(config.client_cas))
+            } else {
+                None
+            },
             retransmit_interval,
             //log: logger,
             initial_epoch: 0,
